pub fn git_working_dir() -> Result<Option<String>, GitDirError>Expand description
Return None if cwd not in a Git repository, Some with the path if cwd is, and return an error if the path cannot be decoded as a string or Git is not available.
pub fn git_working_dir() -> Result<Option<String>, GitDirError>Return None if cwd not in a Git repository, Some with the path if cwd is, and return an error if the path cannot be decoded as a string or Git is not available.